# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = ['NetworkStorageArgs', 'NetworkStorage']

@pulumi.input_type
class NetworkStorageArgs:
    def __init__(__self__, *,
                 data_center_id: pulumi.Input[str],
                 name: pulumi.Input[str],
                 size: pulumi.Input[int]):
        """
        The set of arguments for constructing a NetworkStorage resource.
        """
        pulumi.set(__self__, "data_center_id", data_center_id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "size", size)

    @property
    @pulumi.getter(name="dataCenterId")
    def data_center_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "data_center_id")

    @data_center_id.setter
    def data_center_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "data_center_id", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def size(self) -> pulumi.Input[int]:
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: pulumi.Input[int]):
        pulumi.set(self, "size", value)


class NetworkStorage(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_center_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Create a NetworkStorage resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkStorageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a NetworkStorage resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param NetworkStorageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkStorageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_center_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkStorageArgs.__new__(NetworkStorageArgs)

            if data_center_id is None and not opts.urn:
                raise TypeError("Missing required property 'data_center_id'")
            __props__.__dict__["data_center_id"] = data_center_id
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            if size is None and not opts.urn:
                raise TypeError("Missing required property 'size'")
            __props__.__dict__["size"] = size
            __props__.__dict__["network_storage"] = None
        super(NetworkStorage, __self__).__init__(
            'runpod:index:NetworkStorage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'NetworkStorage':
        """
        Get an existing NetworkStorage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = NetworkStorageArgs.__new__(NetworkStorageArgs)

        __props__.__dict__["data_center_id"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["network_storage"] = None
        __props__.__dict__["size"] = None
        return NetworkStorage(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dataCenterId")
    def data_center_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "data_center_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkStorage")
    def network_storage(self) -> pulumi.Output['outputs.NetworkStorage']:
        return pulumi.get(self, "network_storage")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[int]:
        return pulumi.get(self, "size")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = ['EndpointArgs', 'Endpoint']

@pulumi.input_type
class EndpointArgs:
    def __init__(__self__, *,
                 gpu_ids: pulumi.Input[str],
                 name: pulumi.Input[str],
                 idle_timeout: Optional[pulumi.Input[int]] = None,
                 locations: Optional[pulumi.Input[str]] = None,
                 network_volume_id: Optional[pulumi.Input[str]] = None,
                 scaler_type: Optional[pulumi.Input[str]] = None,
                 scaler_value: Optional[pulumi.Input[int]] = None,
                 template_id: Optional[pulumi.Input[str]] = None,
                 workers_max: Optional[pulumi.Input[int]] = None,
                 workers_min: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Endpoint resource.
        """
        pulumi.set(__self__, "gpu_ids", gpu_ids)
        pulumi.set(__self__, "name", name)
        if idle_timeout is not None:
            pulumi.set(__self__, "idle_timeout", idle_timeout)
        if locations is not None:
            pulumi.set(__self__, "locations", locations)
        if network_volume_id is not None:
            pulumi.set(__self__, "network_volume_id", network_volume_id)
        if scaler_type is not None:
            pulumi.set(__self__, "scaler_type", scaler_type)
        if scaler_value is not None:
            pulumi.set(__self__, "scaler_value", scaler_value)
        if template_id is not None:
            pulumi.set(__self__, "template_id", template_id)
        if workers_max is not None:
            pulumi.set(__self__, "workers_max", workers_max)
        if workers_min is not None:
            pulumi.set(__self__, "workers_min", workers_min)

    @property
    @pulumi.getter(name="gpuIds")
    def gpu_ids(self) -> pulumi.Input[str]:
        return pulumi.get(self, "gpu_ids")

    @gpu_ids.setter
    def gpu_ids(self, value: pulumi.Input[str]):
        pulumi.set(self, "gpu_ids", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="idleTimeout")
    def idle_timeout(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "idle_timeout")

    @idle_timeout.setter
    def idle_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "idle_timeout", value)

    @property
    @pulumi.getter
    def locations(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "locations")

    @locations.setter
    def locations(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "locations", value)

    @property
    @pulumi.getter(name="networkVolumeId")
    def network_volume_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "network_volume_id")

    @network_volume_id.setter
    def network_volume_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_volume_id", value)

    @property
    @pulumi.getter(name="scalerType")
    def scaler_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "scaler_type")

    @scaler_type.setter
    def scaler_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scaler_type", value)

    @property
    @pulumi.getter(name="scalerValue")
    def scaler_value(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "scaler_value")

    @scaler_value.setter
    def scaler_value(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "scaler_value", value)

    @property
    @pulumi.getter(name="templateId")
    def template_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "template_id")

    @template_id.setter
    def template_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template_id", value)

    @property
    @pulumi.getter(name="workersMax")
    def workers_max(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "workers_max")

    @workers_max.setter
    def workers_max(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "workers_max", value)

    @property
    @pulumi.getter(name="workersMin")
    def workers_min(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "workers_min")

    @workers_min.setter
    def workers_min(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "workers_min", value)


class Endpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 gpu_ids: Optional[pulumi.Input[str]] = None,
                 idle_timeout: Optional[pulumi.Input[int]] = None,
                 locations: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_volume_id: Optional[pulumi.Input[str]] = None,
                 scaler_type: Optional[pulumi.Input[str]] = None,
                 scaler_value: Optional[pulumi.Input[int]] = None,
                 template_id: Optional[pulumi.Input[str]] = None,
                 workers_max: Optional[pulumi.Input[int]] = None,
                 workers_min: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Create a Endpoint resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EndpointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Endpoint resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param EndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 gpu_ids: Optional[pulumi.Input[str]] = None,
                 idle_timeout: Optional[pulumi.Input[int]] = None,
                 locations: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_volume_id: Optional[pulumi.Input[str]] = None,
                 scaler_type: Optional[pulumi.Input[str]] = None,
                 scaler_value: Optional[pulumi.Input[int]] = None,
                 template_id: Optional[pulumi.Input[str]] = None,
                 workers_max: Optional[pulumi.Input[int]] = None,
                 workers_min: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EndpointArgs.__new__(EndpointArgs)

            if gpu_ids is None and not opts.urn:
                raise TypeError("Missing required property 'gpu_ids'")
            __props__.__dict__["gpu_ids"] = gpu_ids
            __props__.__dict__["idle_timeout"] = idle_timeout
            __props__.__dict__["locations"] = locations
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["network_volume_id"] = network_volume_id
            __props__.__dict__["scaler_type"] = scaler_type
            __props__.__dict__["scaler_value"] = scaler_value
            __props__.__dict__["template_id"] = template_id
            __props__.__dict__["workers_max"] = workers_max
            __props__.__dict__["workers_min"] = workers_min
            __props__.__dict__["endpoint"] = None
        super(Endpoint, __self__).__init__(
            'runpod:index:Endpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'Endpoint':
        """
        Get an existing Endpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = EndpointArgs.__new__(EndpointArgs)

        __props__.__dict__["endpoint"] = None
        __props__.__dict__["gpu_ids"] = None
        __props__.__dict__["idle_timeout"] = None
        __props__.__dict__["locations"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["network_volume_id"] = None
        __props__.__dict__["scaler_type"] = None
        __props__.__dict__["scaler_value"] = None
        __props__.__dict__["template_id"] = None
        __props__.__dict__["workers_max"] = None
        __props__.__dict__["workers_min"] = None
        return Endpoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def endpoint(self) -> pulumi.Output['outputs.Endpoint']:
        return pulumi.get(self, "endpoint")

    @property
    @pulumi.getter(name="gpuIds")
    def gpu_ids(self) -> pulumi.Output[str]:
        return pulumi.get(self, "gpu_ids")

    @property
    @pulumi.getter(name="idleTimeout")
    def idle_timeout(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "idle_timeout")

    @property
    @pulumi.getter
    def locations(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "locations")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkVolumeId")
    def network_volume_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "network_volume_id")

    @property
    @pulumi.getter(name="scalerType")
    def scaler_type(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "scaler_type")

    @property
    @pulumi.getter(name="scalerValue")
    def scaler_value(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "scaler_value")

    @property
    @pulumi.getter(name="templateId")
    def template_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "template_id")

    @property
    @pulumi.getter(name="workersMax")
    def workers_max(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "workers_max")

    @property
    @pulumi.getter(name="workersMin")
    def workers_min(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "workers_min")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'PodEnvArgs',
    'SavingsPlanInputArgs',
]

@pulumi.input_type
class PodEnvArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[str],
                 value: pulumi.Input[str]):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class SavingsPlanInputArgs:
    def __init__(__self__, *,
                 plan_length: pulumi.Input[str],
                 upfront_cost: pulumi.Input[float]):
        pulumi.set(__self__, "plan_length", plan_length)
        pulumi.set(__self__, "upfront_cost", upfront_cost)

    @property
    @pulumi.getter(name="planLength")
    def plan_length(self) -> pulumi.Input[str]:
        return pulumi.get(self, "plan_length")

    @plan_length.setter
    def plan_length(self, value: pulumi.Input[str]):
        pulumi.set(self, "plan_length", value)

    @property
    @pulumi.getter(name="upfrontCost")
    def upfront_cost(self) -> pulumi.Input[float]:
        return pulumi.get(self, "upfront_cost")

    @upfront_cost.setter
    def upfront_cost(self, value: pulumi.Input[float]):
        pulumi.set(self, "upfront_cost", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('runpod')


class _ExportableConfig(types.ModuleType):
    @property
    def token(self) -> Optional[str]:
        """
        Runpod API Token
        """
        return __config__.get('token')




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TemplateArgs', 'Template']

@pulumi.input_type
class TemplateArgs:
    def __init__(__self__, *,
                 container_disk_in_gb: pulumi.Input[int],
                 docker_args: pulumi.Input[str],
                 env: pulumi.Input[Sequence[pulumi.Input['PodEnvArgs']]],
                 image_name: pulumi.Input[str],
                 name: pulumi.Input[str],
                 volume_in_gb: pulumi.Input[int],
                 container_registry_auth_id: Optional[pulumi.Input[str]] = None,
                 is_public: Optional[pulumi.Input[bool]] = None,
                 is_serverless: Optional[pulumi.Input[bool]] = None,
                 ports: Optional[pulumi.Input[str]] = None,
                 readme: Optional[pulumi.Input[str]] = None,
                 start_jupyter: Optional[pulumi.Input[bool]] = None,
                 start_ssh: Optional[pulumi.Input[bool]] = None,
                 volume_mount_path: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Template resource.
        """
        pulumi.set(__self__, "container_disk_in_gb", container_disk_in_gb)
        pulumi.set(__self__, "docker_args", docker_args)
        pulumi.set(__self__, "env", env)
        pulumi.set(__self__, "image_name", image_name)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "volume_in_gb", volume_in_gb)
        if container_registry_auth_id is not None:
            pulumi.set(__self__, "container_registry_auth_id", container_registry_auth_id)
        if is_public is not None:
            pulumi.set(__self__, "is_public", is_public)
        if is_serverless is not None:
            pulumi.set(__self__, "is_serverless", is_serverless)
        if ports is not None:
            pulumi.set(__self__, "ports", ports)
        if readme is not None:
            pulumi.set(__self__, "readme", readme)
        if start_jupyter is not None:
            pulumi.set(__self__, "start_jupyter", start_jupyter)
        if start_ssh is not None:
            pulumi.set(__self__, "start_ssh", start_ssh)
        if volume_mount_path is not None:
            pulumi.set(__self__, "volume_mount_path", volume_mount_path)

    @property
    @pulumi.getter(name="containerDiskInGb")
    def container_disk_in_gb(self) -> pulumi.Input[int]:
        return pulumi.get(self, "container_disk_in_gb")

    @container_disk_in_gb.setter
    def container_disk_in_gb(self, value: pulumi.Input[int]):
        pulumi.set(self, "container_disk_in_gb", value)

    @property
    @pulumi.getter(name="dockerArgs")
    def docker_args(self) -> pulumi.Input[str]:
        return pulumi.get(self, "docker_args")

    @docker_args.setter
    def docker_args(self, value: pulumi.Input[str]):
        pulumi.set(self, "docker_args", value)

    @property
    @pulumi.getter
    def env(self) -> pulumi.Input[Sequence[pulumi.Input['PodEnvArgs']]]:
        return pulumi.get(self, "env")

    @env.setter
    def env(self, value: pulumi.Input[Sequence[pulumi.Input['PodEnvArgs']]]):
        pulumi.set(self, "env", value)

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "image_name")

    @image_name.setter
    def image_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "image_name", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="volumeInGb")
    def volume_in_gb(self) -> pulumi.Input[int]:
        return pulumi.get(self, "volume_in_gb")

    @volume_in_gb.setter
    def volume_in_gb(self, value: pulumi.Input[int]):
        pulumi.set(self, "volume_in_gb", value)

    @property
    @pulumi.getter(name="containerRegistryAuthId")
    def container_registry_auth_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "container_registry_auth_id")

    @container_registry_auth_id.setter
    def container_registry_auth_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "container_registry_auth_id", value)

    @property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "is_public")

    @is_public.setter
    def is_public(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_public", value)

    @property
    @pulumi.getter(name="isServerless")
    def is_serverless(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "is_serverless")

    @is_serverless.setter
    def is_serverless(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_serverless", value)

    @property
    @pulumi.getter
    def ports(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ports")

    @ports.setter
    def ports(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ports", value)

    @property
    @pulumi.getter
    def readme(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "readme")

    @readme.setter
    def readme(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "readme", value)

    @property
    @pulumi.getter(name="startJupyter")
    def start_jupyter(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "start_jupyter")

    @start_jupyter.setter
    def start_jupyter(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "start_jupyter", value)

    @property
    @pulumi.getter(name="startSsh")
    def start_ssh(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "start_ssh")

    @start_ssh.setter
    def start_ssh(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "start_ssh", value)

    @property
    @pulumi.getter(name="volumeMountPath")
    def volume_mount_path(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "volume_mount_path")

    @volume_mount_path.setter
    def volume_mount_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "volume_mount_path", value)


class Template(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 container_disk_in_gb: Optional[pulumi.Input[int]] = None,
                 container_registry_auth_id: Optional[pulumi.Input[str]] = None,
                 docker_args: Optional[pulumi.Input[str]] = None,
                 env: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PodEnvArgs']]]]] = None,
                 image_name: Optional[pulumi.Input[str]] = None,
                 is_public: Optional[pulumi.Input[bool]] = None,
                 is_serverless: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ports: Optional[pulumi.Input[str]] = None,
                 readme: Optional[pulumi.Input[str]] = None,
                 start_jupyter: Optional[pulumi.Input[bool]] = None,
                 start_ssh: Optional[pulumi.Input[bool]] = None,
                 volume_in_gb: Optional[pulumi.Input[int]] = None,
                 volume_mount_path: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a Template resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TemplateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Template resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param TemplateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TemplateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 container_disk_in_gb: Optional[pulumi.Input[int]] = None,
                 container_registry_auth_id: Optional[pulumi.Input[str]] = None,
                 docker_args: Optional[pulumi.Input[str]] = None,
                 env: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PodEnvArgs']]]]] = None,
                 image_name: Optional[pulumi.Input[str]] = None,
                 is_public: Optional[pulumi.Input[bool]] = None,
                 is_serverless: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ports: Optional[pulumi.Input[str]] = None,
                 readme: Optional[pulumi.Input[str]] = None,
                 start_jupyter: Optional[pulumi.Input[bool]] = None,
                 start_ssh: Optional[pulumi.Input[bool]] = None,
                 volume_in_gb: Optional[pulumi.Input[int]] = None,
                 volume_mount_path: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TemplateArgs.__new__(TemplateArgs)

            if container_disk_in_gb is None and not opts.urn:
                raise TypeError("Missing required property 'container_disk_in_gb'")
            __props__.__dict__["container_disk_in_gb"] = container_disk_in_gb
            __props__.__dict__["container_registry_auth_id"] = container_registry_auth_id
            if docker_args is None and not opts.urn:
                raise TypeError("Missing required property 'docker_args'")
            __props__.__dict__["docker_args"] = docker_args
            if env is None and not opts.urn:
                raise TypeError("Missing required property 'env'")
            __props__.__dict__["env"] = env
            if image_name is None and not opts.urn:
                raise TypeError("Missing required property 'image_name'")
            __props__.__dict__["image_name"] = image_name
            __props__.__dict__["is_public"] = is_public
            __props__.__dict__["is_serverless"] = is_serverless
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["ports"] = ports
            __props__.__dict__["readme"] = readme
            __props__.__dict__["start_jupyter"] = start_jupyter
            __props__.__dict__["start_ssh"] = start_ssh
            if volume_in_gb is None and not opts.urn:
                raise TypeError("Missing required property 'volume_in_gb'")
            __props__.__dict__["volume_in_gb"] = volume_in_gb
            __props__.__dict__["volume_mount_path"] = volume_mount_path
            __props__.__dict__["template"] = None
        super(Template, __self__).__init__(
            'runpod:index:Template',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'Template':
        """
        Get an existing Template resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = TemplateArgs.__new__(TemplateArgs)

        __props__.__dict__["container_disk_in_gb"] = None
        __props__.__dict__["container_registry_auth_id"] = None
        __props__.__dict__["docker_args"] = None
        __props__.__dict__["env"] = None
        __props__.__dict__["image_name"] = None
        __props__.__dict__["is_public"] = None
        __props__.__dict__["is_serverless"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["ports"] = None
        __props__.__dict__["readme"] = None
        __props__.__dict__["start_jupyter"] = None
        __props__.__dict__["start_ssh"] = None
        __props__.__dict__["template"] = None
        __props__.__dict__["volume_in_gb"] = None
        __props__.__dict__["volume_mount_path"] = None
        return Template(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="containerDiskInGb")
    def container_disk_in_gb(self) -> pulumi.Output[int]:
        return pulumi.get(self, "container_disk_in_gb")

    @property
    @pulumi.getter(name="containerRegistryAuthId")
    def container_registry_auth_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "container_registry_auth_id")

    @property
    @pulumi.getter(name="dockerArgs")
    def docker_args(self) -> pulumi.Output[str]:
        return pulumi.get(self, "docker_args")

    @property
    @pulumi.getter
    def env(self) -> pulumi.Output[Sequence['outputs.PodEnv']]:
        return pulumi.get(self, "env")

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "image_name")

    @property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "is_public")

    @property
    @pulumi.getter(name="isServerless")
    def is_serverless(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "is_serverless")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def ports(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "ports")

    @property
    @pulumi.getter
    def readme(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "readme")

    @property
    @pulumi.getter(name="startJupyter")
    def start_jupyter(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "start_jupyter")

    @property
    @pulumi.getter(name="startSsh")
    def start_ssh(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "start_ssh")

    @property
    @pulumi.getter
    def template(self) -> pulumi.Output['outputs.Template']:
        return pulumi.get(self, "template")

    @property
    @pulumi.getter(name="volumeInGb")
    def volume_in_gb(self) -> pulumi.Output[int]:
        return pulumi.get(self, "volume_in_gb")

    @property
    @pulumi.getter(name="volumeMountPath")
    def volume_mount_path(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "volume_mount_path")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PodArgs', 'Pod']

@pulumi.input_type
class PodArgs:
    def __init__(__self__, *,
                 gpu_count: pulumi.Input[int],
                 gpu_type_id: pulumi.Input[str],
                 image_name: pulumi.Input[str],
                 ai_api_id: Optional[pulumi.Input[str]] = None,
                 cloud_type: Optional[pulumi.Input[str]] = None,
                 container_disk_in_gb: Optional[pulumi.Input[int]] = None,
                 country_code: Optional[pulumi.Input[str]] = None,
                 cuda_version: Optional[pulumi.Input[str]] = None,
                 data_center_id: Optional[pulumi.Input[str]] = None,
                 deploy_cost: Optional[pulumi.Input[float]] = None,
                 docker_args: Optional[pulumi.Input[str]] = None,
                 env: Optional[pulumi.Input[Sequence[pulumi.Input['PodEnvArgs']]]] = None,
                 gpu_type_id_list: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 min_disk: Optional[pulumi.Input[int]] = None,
                 min_download: Optional[pulumi.Input[int]] = None,
                 min_memory_in_gb: Optional[pulumi.Input[int]] = None,
                 min_upload: Optional[pulumi.Input[int]] = None,
                 min_vcpu_count: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_volume_id: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 ports: Optional[pulumi.Input[str]] = None,
                 savings_plan: Optional[pulumi.Input['SavingsPlanInputArgs']] = None,
                 start_jupyter: Optional[pulumi.Input[bool]] = None,
                 start_ssh: Optional[pulumi.Input[bool]] = None,
                 stop_after: Optional[pulumi.Input[str]] = None,
                 support_public_ip: Optional[pulumi.Input[bool]] = None,
                 template_id: Optional[pulumi.Input[str]] = None,
                 terminate_after: Optional[pulumi.Input[str]] = None,
                 volume_in_gb: Optional[pulumi.Input[int]] = None,
                 volume_key: Optional[pulumi.Input[str]] = None,
                 volume_mount_path: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Pod resource.
        """
        pulumi.set(__self__, "gpu_count", gpu_count)
        pulumi.set(__self__, "gpu_type_id", gpu_type_id)
        pulumi.set(__self__, "image_name", image_name)
        if ai_api_id is not None:
            pulumi.set(__self__, "ai_api_id", ai_api_id)
        if cloud_type is not None:
            pulumi.set(__self__, "cloud_type", cloud_type)
        if container_disk_in_gb is not None:
            pulumi.set(__self__, "container_disk_in_gb", container_disk_in_gb)
        if country_code is not None:
            pulumi.set(__self__, "country_code", country_code)
        if cuda_version is not None:
            pulumi.set(__self__, "cuda_version", cuda_version)
        if data_center_id is not None:
            pulumi.set(__self__, "data_center_id", data_center_id)
        if deploy_cost is not None:
            pulumi.set(__self__, "deploy_cost", deploy_cost)
        if docker_args is not None:
            pulumi.set(__self__, "docker_args", docker_args)
        if env is not None:
            pulumi.set(__self__, "env", env)
        if gpu_type_id_list is not None:
            pulumi.set(__self__, "gpu_type_id_list", gpu_type_id_list)
        if min_disk is not None:
            pulumi.set(__self__, "min_disk", min_disk)
        if min_download is not None:
            pulumi.set(__self__, "min_download", min_download)
        if min_memory_in_gb is not None:
            pulumi.set(__self__, "min_memory_in_gb", min_memory_in_gb)
        if min_upload is not None:
            pulumi.set(__self__, "min_upload", min_upload)
        if min_vcpu_count is not None:
            pulumi.set(__self__, "min_vcpu_count", min_vcpu_count)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_volume_id is not None:
            pulumi.set(__self__, "network_volume_id", network_volume_id)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if ports is not None:
            pulumi.set(__self__, "ports", ports)
        if savings_plan is not None:
            pulumi.set(__self__, "savings_plan", savings_plan)
        if start_jupyter is not None:
            pulumi.set(__self__, "start_jupyter", start_jupyter)
        if start_ssh is not None:
            pulumi.set(__self__, "start_ssh", start_ssh)
        if stop_after is not None:
            pulumi.set(__self__, "stop_after", stop_after)
        if support_public_ip is not None:
            pulumi.set(__self__, "support_public_ip", support_public_ip)
        if template_id is not None:
            pulumi.set(__self__, "template_id", template_id)
        if terminate_after is not None:
            pulumi.set(__self__, "terminate_after", terminate_after)
        if volume_in_gb is not None:
            pulumi.set(__self__, "volume_in_gb", volume_in_gb)
        if volume_key is not None:
            pulumi.set(__self__, "volume_key", volume_key)
        if volume_mount_path is not None:
            pulumi.set(__self__, "volume_mount_path", volume_mount_path)

    @property
    @pulumi.getter(name="gpuCount")
    def gpu_count(self) -> pulumi.Input[int]:
        return pulumi.get(self, "gpu_count")

    @gpu_count.setter
    def gpu_count(self, value: pulumi.Input[int]):
        pulumi.set(self, "gpu_count", value)

    @property
    @pulumi.getter(name="gpuTypeId")
    def gpu_type_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "gpu_type_id")

    @gpu_type_id.setter
    def gpu_type_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "gpu_type_id", value)

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "image_name")

    @image_name.setter
    def image_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "image_name", value)

    @property
    @pulumi.getter(name="aiApiId")
    def ai_api_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ai_api_id")

    @ai_api_id.setter
    def ai_api_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ai_api_id", value)

    @property
    @pulumi.getter(name="cloudType")
    def cloud_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cloud_type")

    @cloud_type.setter
    def cloud_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloud_type", value)

    @property
    @pulumi.getter(name="containerDiskInGb")
    def container_disk_in_gb(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "container_disk_in_gb")

    @container_disk_in_gb.setter
    def container_disk_in_gb(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "container_disk_in_gb", value)

    @property
    @pulumi.getter(name="countryCode")
    def country_code(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "country_code")

    @country_code.setter
    def country_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "country_code", value)

    @property
    @pulumi.getter(name="cudaVersion")
    def cuda_version(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cuda_version")

    @cuda_version.setter
    def cuda_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cuda_version", value)

    @property
    @pulumi.getter(name="dataCenterId")
    def data_center_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "data_center_id")

    @data_center_id.setter
    def data_center_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_center_id", value)

    @property
    @pulumi.getter(name="deployCost")
    def deploy_cost(self) -> Optional[pulumi.Input[float]]:
        return pulumi.get(self, "deploy_cost")

    @deploy_cost.setter
    def deploy_cost(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "deploy_cost", value)

    @property
    @pulumi.getter(name="dockerArgs")
    def docker_args(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "docker_args")

    @docker_args.setter
    def docker_args(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "docker_args", value)

    @property
    @pulumi.getter
    def env(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PodEnvArgs']]]]:
        return pulumi.get(self, "env")

    @env.setter
    def env(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PodEnvArgs']]]]):
        pulumi.set(self, "env", value)

    @property
    @pulumi.getter(name="gpuTypeIdList")
    def gpu_type_id_list(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "gpu_type_id_list")

    @gpu_type_id_list.setter
    def gpu_type_id_list(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "gpu_type_id_list", value)

    @property
    @pulumi.getter(name="minDisk")
    def min_disk(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "min_disk")

    @min_disk.setter
    def min_disk(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "min_disk", value)

    @property
    @pulumi.getter(name="minDownload")
    def min_download(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "min_download")

    @min_download.setter
    def min_download(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "min_download", value)

    @property
    @pulumi.getter(name="minMemoryInGb")
    def min_memory_in_gb(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "min_memory_in_gb")

    @min_memory_in_gb.setter
    def min_memory_in_gb(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "min_memory_in_gb", value)

    @property
    @pulumi.getter(name="minUpload")
    def min_upload(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "min_upload")

    @min_upload.setter
    def min_upload(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "min_upload", value)

    @property
    @pulumi.getter(name="minVcpuCount")
    def min_vcpu_count(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "min_vcpu_count")

    @min_vcpu_count.setter
    def min_vcpu_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "min_vcpu_count", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="networkVolumeId")
    def network_volume_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "network_volume_id")

    @network_volume_id.setter
    def network_volume_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_volume_id", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def ports(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ports")

    @ports.setter
    def ports(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ports", value)

    @property
    @pulumi.getter(name="savingsPlan")
    def savings_plan(self) -> Optional[pulumi.Input['SavingsPlanInputArgs']]:
        return pulumi.get(self, "savings_plan")

    @savings_plan.setter
    def savings_plan(self, value: Optional[pulumi.Input['SavingsPlanInputArgs']]):
        pulumi.set(self, "savings_plan", value)

    @property
    @pulumi.getter(name="startJupyter")
    def start_jupyter(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "start_jupyter")

    @start_jupyter.setter
    def start_jupyter(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "start_jupyter", value)

    @property
    @pulumi.getter(name="startSsh")
    def start_ssh(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "start_ssh")

    @start_ssh.setter
    def start_ssh(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "start_ssh", value)

    @property
    @pulumi.getter(name="stopAfter")
    def stop_after(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "stop_after")

    @stop_after.setter
    def stop_after(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stop_after", value)

    @property
    @pulumi.getter(name="supportPublicIp")
    def support_public_ip(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "support_public_ip")

    @support_public_ip.setter
    def support_public_ip(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "support_public_ip", value)

    @property
    @pulumi.getter(name="templateId")
    def template_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "template_id")

    @template_id.setter
    def template_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template_id", value)

    @property
    @pulumi.getter(name="terminateAfter")
    def terminate_after(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "terminate_after")

    @terminate_after.setter
    def terminate_after(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "terminate_after", value)

    @property
    @pulumi.getter(name="volumeInGb")
    def volume_in_gb(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "volume_in_gb")

    @volume_in_gb.setter
    def volume_in_gb(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "volume_in_gb", value)

    @property
    @pulumi.getter(name="volumeKey")
    def volume_key(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "volume_key")

    @volume_key.setter
    def volume_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "volume_key", value)

    @property
    @pulumi.getter(name="volumeMountPath")
    def volume_mount_path(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "volume_mount_path")

    @volume_mount_path.setter
    def volume_mount_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "volume_mount_path", value)


class Pod(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ai_api_id: Optional[pulumi.Input[str]] = None,
                 cloud_type: Optional[pulumi.Input[str]] = None,
                 container_disk_in_gb: Optional[pulumi.Input[int]] = None,
                 country_code: Optional[pulumi.Input[str]] = None,
                 cuda_version: Optional[pulumi.Input[str]] = None,
                 data_center_id: Optional[pulumi.Input[str]] = None,
                 deploy_cost: Optional[pulumi.Input[float]] = None,
                 docker_args: Optional[pulumi.Input[str]] = None,
                 env: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PodEnvArgs']]]]] = None,
                 gpu_count: Optional[pulumi.Input[int]] = None,
                 gpu_type_id: Optional[pulumi.Input[str]] = None,
                 gpu_type_id_list: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 image_name: Optional[pulumi.Input[str]] = None,
                 min_disk: Optional[pulumi.Input[int]] = None,
                 min_download: Optional[pulumi.Input[int]] = None,
                 min_memory_in_gb: Optional[pulumi.Input[int]] = None,
                 min_upload: Optional[pulumi.Input[int]] = None,
                 min_vcpu_count: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_volume_id: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 ports: Optional[pulumi.Input[str]] = None,
                 savings_plan: Optional[pulumi.Input[pulumi.InputType['SavingsPlanInputArgs']]] = None,
                 start_jupyter: Optional[pulumi.Input[bool]] = None,
                 start_ssh: Optional[pulumi.Input[bool]] = None,
                 stop_after: Optional[pulumi.Input[str]] = None,
                 support_public_ip: Optional[pulumi.Input[bool]] = None,
                 template_id: Optional[pulumi.Input[str]] = None,
                 terminate_after: Optional[pulumi.Input[str]] = None,
                 volume_in_gb: Optional[pulumi.Input[int]] = None,
                 volume_key: Optional[pulumi.Input[str]] = None,
                 volume_mount_path: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a Pod resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PodArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Pod resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param PodArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PodArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ai_api_id: Optional[pulumi.Input[str]] = None,
                 cloud_type: Optional[pulumi.Input[str]] = None,
                 container_disk_in_gb: Optional[pulumi.Input[int]] = None,
                 country_code: Optional[pulumi.Input[str]] = None,
                 cuda_version: Optional[pulumi.Input[str]] = None,
                 data_center_id: Optional[pulumi.Input[str]] = None,
                 deploy_cost: Optional[pulumi.Input[float]] = None,
                 docker_args: Optional[pulumi.Input[str]] = None,
                 env: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PodEnvArgs']]]]] = None,
                 gpu_count: Optional[pulumi.Input[int]] = None,
                 gpu_type_id: Optional[pulumi.Input[str]] = None,
                 gpu_type_id_list: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 image_name: Optional[pulumi.Input[str]] = None,
                 min_disk: Optional[pulumi.Input[int]] = None,
                 min_download: Optional[pulumi.Input[int]] = None,
                 min_memory_in_gb: Optional[pulumi.Input[int]] = None,
                 min_upload: Optional[pulumi.Input[int]] = None,
                 min_vcpu_count: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_volume_id: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 ports: Optional[pulumi.Input[str]] = None,
                 savings_plan: Optional[pulumi.Input[pulumi.InputType['SavingsPlanInputArgs']]] = None,
                 start_jupyter: Optional[pulumi.Input[bool]] = None,
                 start_ssh: Optional[pulumi.Input[bool]] = None,
                 stop_after: Optional[pulumi.Input[str]] = None,
                 support_public_ip: Optional[pulumi.Input[bool]] = None,
                 template_id: Optional[pulumi.Input[str]] = None,
                 terminate_after: Optional[pulumi.Input[str]] = None,
                 volume_in_gb: Optional[pulumi.Input[int]] = None,
                 volume_key: Optional[pulumi.Input[str]] = None,
                 volume_mount_path: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PodArgs.__new__(PodArgs)

            __props__.__dict__["ai_api_id"] = ai_api_id
            __props__.__dict__["cloud_type"] = cloud_type
            __props__.__dict__["container_disk_in_gb"] = container_disk_in_gb
            __props__.__dict__["country_code"] = country_code
            __props__.__dict__["cuda_version"] = cuda_version
            __props__.__dict__["data_center_id"] = data_center_id
            __props__.__dict__["deploy_cost"] = deploy_cost
            __props__.__dict__["docker_args"] = docker_args
            __props__.__dict__["env"] = env
            if gpu_count is None and not opts.urn:
                raise TypeError("Missing required property 'gpu_count'")
            __props__.__dict__["gpu_count"] = gpu_count
            if gpu_type_id is None and not opts.urn:
                raise TypeError("Missing required property 'gpu_type_id'")
            __props__.__dict__["gpu_type_id"] = gpu_type_id
            __props__.__dict__["gpu_type_id_list"] = gpu_type_id_list
            if image_name is None and not opts.urn:
                raise TypeError("Missing required property 'image_name'")
            __props__.__dict__["image_name"] = image_name
            __props__.__dict__["min_disk"] = min_disk
            __props__.__dict__["min_download"] = min_download
            __props__.__dict__["min_memory_in_gb"] = min_memory_in_gb
            __props__.__dict__["min_upload"] = min_upload
            __props__.__dict__["min_vcpu_count"] = min_vcpu_count
            __props__.__dict__["name"] = name
            __props__.__dict__["network_volume_id"] = network_volume_id
            __props__.__dict__["port"] = port
            __props__.__dict__["ports"] = ports
            __props__.__dict__["savings_plan"] = savings_plan
            __props__.__dict__["start_jupyter"] = start_jupyter
            __props__.__dict__["start_ssh"] = start_ssh
            __props__.__dict__["stop_after"] = stop_after
            __props__.__dict__["support_public_ip"] = support_public_ip
            __props__.__dict__["template_id"] = template_id
            __props__.__dict__["terminate_after"] = terminate_after
            __props__.__dict__["volume_in_gb"] = volume_in_gb
            __props__.__dict__["volume_key"] = volume_key
            __props__.__dict__["volume_mount_path"] = volume_mount_path
            __props__.__dict__["pod"] = None
        super(Pod, __self__).__init__(
            'runpod:index:Pod',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'Pod':
        """
        Get an existing Pod resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = PodArgs.__new__(PodArgs)

        __props__.__dict__["ai_api_id"] = None
        __props__.__dict__["cloud_type"] = None
        __props__.__dict__["container_disk_in_gb"] = None
        __props__.__dict__["country_code"] = None
        __props__.__dict__["cuda_version"] = None
        __props__.__dict__["data_center_id"] = None
        __props__.__dict__["deploy_cost"] = None
        __props__.__dict__["docker_args"] = None
        __props__.__dict__["env"] = None
        __props__.__dict__["gpu_count"] = None
        __props__.__dict__["gpu_type_id"] = None
        __props__.__dict__["gpu_type_id_list"] = None
        __props__.__dict__["image_name"] = None
        __props__.__dict__["min_disk"] = None
        __props__.__dict__["min_download"] = None
        __props__.__dict__["min_memory_in_gb"] = None
        __props__.__dict__["min_upload"] = None
        __props__.__dict__["min_vcpu_count"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["network_volume_id"] = None
        __props__.__dict__["pod"] = None
        __props__.__dict__["port"] = None
        __props__.__dict__["ports"] = None
        __props__.__dict__["savings_plan"] = None
        __props__.__dict__["start_jupyter"] = None
        __props__.__dict__["start_ssh"] = None
        __props__.__dict__["stop_after"] = None
        __props__.__dict__["support_public_ip"] = None
        __props__.__dict__["template_id"] = None
        __props__.__dict__["terminate_after"] = None
        __props__.__dict__["volume_in_gb"] = None
        __props__.__dict__["volume_key"] = None
        __props__.__dict__["volume_mount_path"] = None
        return Pod(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="aiApiId")
    def ai_api_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "ai_api_id")

    @property
    @pulumi.getter(name="cloudType")
    def cloud_type(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "cloud_type")

    @property
    @pulumi.getter(name="containerDiskInGb")
    def container_disk_in_gb(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "container_disk_in_gb")

    @property
    @pulumi.getter(name="countryCode")
    def country_code(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "country_code")

    @property
    @pulumi.getter(name="cudaVersion")
    def cuda_version(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "cuda_version")

    @property
    @pulumi.getter(name="dataCenterId")
    def data_center_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "data_center_id")

    @property
    @pulumi.getter(name="deployCost")
    def deploy_cost(self) -> pulumi.Output[Optional[float]]:
        return pulumi.get(self, "deploy_cost")

    @property
    @pulumi.getter(name="dockerArgs")
    def docker_args(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "docker_args")

    @property
    @pulumi.getter
    def env(self) -> pulumi.Output[Optional[Sequence['outputs.PodEnv']]]:
        return pulumi.get(self, "env")

    @property
    @pulumi.getter(name="gpuCount")
    def gpu_count(self) -> pulumi.Output[int]:
        return pulumi.get(self, "gpu_count")

    @property
    @pulumi.getter(name="gpuTypeId")
    def gpu_type_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "gpu_type_id")

    @property
    @pulumi.getter(name="gpuTypeIdList")
    def gpu_type_id_list(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "gpu_type_id_list")

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "image_name")

    @property
    @pulumi.getter(name="minDisk")
    def min_disk(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "min_disk")

    @property
    @pulumi.getter(name="minDownload")
    def min_download(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "min_download")

    @property
    @pulumi.getter(name="minMemoryInGb")
    def min_memory_in_gb(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "min_memory_in_gb")

    @property
    @pulumi.getter(name="minUpload")
    def min_upload(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "min_upload")

    @property
    @pulumi.getter(name="minVcpuCount")
    def min_vcpu_count(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "min_vcpu_count")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkVolumeId")
    def network_volume_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "network_volume_id")

    @property
    @pulumi.getter
    def pod(self) -> pulumi.Output['outputs.Pod']:
        return pulumi.get(self, "pod")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def ports(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "ports")

    @property
    @pulumi.getter(name="savingsPlan")
    def savings_plan(self) -> pulumi.Output[Optional['outputs.SavingsPlanInput']]:
        return pulumi.get(self, "savings_plan")

    @property
    @pulumi.getter(name="startJupyter")
    def start_jupyter(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "start_jupyter")

    @property
    @pulumi.getter(name="startSsh")
    def start_ssh(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "start_ssh")

    @property
    @pulumi.getter(name="stopAfter")
    def stop_after(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "stop_after")

    @property
    @pulumi.getter(name="supportPublicIp")
    def support_public_ip(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "support_public_ip")

    @property
    @pulumi.getter(name="templateId")
    def template_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "template_id")

    @property
    @pulumi.getter(name="terminateAfter")
    def terminate_after(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "terminate_after")

    @property
    @pulumi.getter(name="volumeInGb")
    def volume_in_gb(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "volume_in_gb")

    @property
    @pulumi.getter(name="volumeKey")
    def volume_key(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "volume_key")

    @property
    @pulumi.getter(name="volumeMountPath")
    def volume_mount_path(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "volume_mount_path")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'DataCenter',
    'Endpoint',
    'Gpu',
    'NetworkStorage',
    'Pod',
    'PodEnv',
    'PodRegistry',
    'SavingsPlanInput',
    'Template',
]

@pulumi.output_type
class DataCenter(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "storageSupport":
            suggest = "storage_support"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DataCenter. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DataCenter.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DataCenter.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 id: str,
                 location: str,
                 name: str,
                 storage_support: bool):
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "location", location)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "storage_support", storage_support)

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def location(self) -> str:
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="storageSupport")
    def storage_support(self) -> bool:
        return pulumi.get(self, "storage_support")


@pulumi.output_type
class Endpoint(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "gpuIds":
            suggest = "gpu_ids"
        elif key == "idleTimeout":
            suggest = "idle_timeout"
        elif key == "networkVolumeId":
            suggest = "network_volume_id"
        elif key == "scalerType":
            suggest = "scaler_type"
        elif key == "scalerValue":
            suggest = "scaler_value"
        elif key == "templateId":
            suggest = "template_id"
        elif key == "workersMax":
            suggest = "workers_max"
        elif key == "workersMin":
            suggest = "workers_min"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in Endpoint. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        Endpoint.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        Endpoint.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 gpu_ids: str,
                 id: str,
                 idle_timeout: int,
                 locations: str,
                 name: str,
                 network_volume_id: str,
                 scaler_type: str,
                 scaler_value: int,
                 template_id: str,
                 workers_max: int,
                 workers_min: int):
        pulumi.set(__self__, "gpu_ids", gpu_ids)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "idle_timeout", idle_timeout)
        pulumi.set(__self__, "locations", locations)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "network_volume_id", network_volume_id)
        pulumi.set(__self__, "scaler_type", scaler_type)
        pulumi.set(__self__, "scaler_value", scaler_value)
        pulumi.set(__self__, "template_id", template_id)
        pulumi.set(__self__, "workers_max", workers_max)
        pulumi.set(__self__, "workers_min", workers_min)

    @property
    @pulumi.getter(name="gpuIds")
    def gpu_ids(self) -> str:
        return pulumi.get(self, "gpu_ids")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="idleTimeout")
    def idle_timeout(self) -> int:
        return pulumi.get(self, "idle_timeout")

    @property
    @pulumi.getter
    def locations(self) -> str:
        return pulumi.get(self, "locations")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkVolumeId")
    def network_volume_id(self) -> str:
        return pulumi.get(self, "network_volume_id")

    @property
    @pulumi.getter(name="scalerType")
    def scaler_type(self) -> str:
        return pulumi.get(self, "scaler_type")

    @property
    @pulumi.getter(name="scalerValue")
    def scaler_value(self) -> int:
        return pulumi.get(self, "scaler_value")

    @property
    @pulumi.getter(name="templateId")
    def template_id(self) -> str:
        return pulumi.get(self, "template_id")

    @property
    @pulumi.getter(name="workersMax")
    def workers_max(self) -> int:
        return pulumi.get(self, "workers_max")

    @property
    @pulumi.getter(name="workersMin")
    def workers_min(self) -> int:
        return pulumi.get(self, "workers_min")


@pulumi.output_type
class Gpu(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "podId":
            suggest = "pod_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in Gpu. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        Gpu.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        Gpu.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 id: str,
                 pod_id: str):
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "pod_id", pod_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="podId")
    def pod_id(self) -> str:
        return pulumi.get(self, "pod_id")


@pulumi.output_type
class NetworkStorage(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dataCenter":
            suggest = "data_center"
        elif key == "dataCenterId":
            suggest = "data_center_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NetworkStorage. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NetworkStorage.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NetworkStorage.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 data_center: 'outputs.DataCenter',
                 data_center_id: str,
                 id: str,
                 name: str,
                 size: int):
        pulumi.set(__self__, "data_center", data_center)
        pulumi.set(__self__, "data_center_id", data_center_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "size", size)

    @property
    @pulumi.getter(name="dataCenter")
    def data_center(self) -> 'outputs.DataCenter':
        return pulumi.get(self, "data_center")

    @property
    @pulumi.getter(name="dataCenterId")
    def data_center_id(self) -> str:
        return pulumi.get(self, "data_center_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def size(self) -> int:
        return pulumi.get(self, "size")


@pulumi.output_type
class Pod(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "adjustedCostPerHr":
            suggest = "adjusted_cost_per_hr"
        elif key == "aiApiId":
            suggest = "ai_api_id"
        elif key == "apiKey":
            suggest = "api_key"
        elif key == "consumerUserId":
            suggest = "consumer_user_id"
        elif key == "containerDiskInGb":
            suggest = "container_disk_in_gb"
        elif key == "containerRegistryAuthId":
            suggest = "container_registry_auth_id"
        elif key == "costMultiplier":
            suggest = "cost_multiplier"
        elif key == "costPerHr":
            suggest = "cost_per_hr"
        elif key == "createdAt":
            suggest = "created_at"
        elif key == "desiredStatus":
            suggest = "desired_status"
        elif key == "dockerArgs":
            suggest = "docker_args"
        elif key == "dockerId":
            suggest = "docker_id"
        elif key == "gpuCount":
            suggest = "gpu_count"
        elif key == "gpuPowerLimitPercent":
            suggest = "gpu_power_limit_percent"
        elif key == "imageName":
            suggest = "image_name"
        elif key == "lastStartedAt":
            suggest = "last_started_at"
        elif key == "lastStatusChange":
            suggest = "last_status_change"
        elif key == "machineId":
            suggest = "machine_id"
        elif key == "memoryInGb":
            suggest = "memory_in_gb"
        elif key == "podType":
            suggest = "pod_type"
        elif key == "templateId":
            suggest = "template_id"
        elif key == "uptimeSeconds":
            suggest = "uptime_seconds"
        elif key == "vcpuCount":
            suggest = "vcpu_count"
        elif key == "volumeEncrypted":
            suggest = "volume_encrypted"
        elif key == "volumeInGb":
            suggest = "volume_in_gb"
        elif key == "volumeKey":
            suggest = "volume_key"
        elif key == "volumeMountPath":
            suggest = "volume_mount_path"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in Pod. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        Pod.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        Pod.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 adjusted_cost_per_hr: float,
                 ai_api_id: str,
                 api_key: str,
                 consumer_user_id: str,
                 container_disk_in_gb: int,
                 container_registry_auth_id: str,
                 cost_multiplier: float,
                 cost_per_hr: float,
                 created_at: str,
                 desired_status: str,
                 docker_args: str,
                 docker_id: str,
                 gpu_count: int,
                 gpu_power_limit_percent: int,
                 id: str,
                 image_name: str,
                 last_started_at: str,
                 last_status_change: str,
                 locked: bool,
                 machine_id: str,
                 memory_in_gb: float,
                 name: str,
                 pod_type: str,
                 port: int,
                 ports: str,
                 registry: 'outputs.PodRegistry',
                 template_id: str,
                 uptime_seconds: int,
                 vcpu_count: float,
                 version: int,
                 volume_encrypted: bool,
                 volume_in_gb: float,
                 volume_key: str,
                 volume_mount_path: str,
                 env: Optional[Sequence[str]] = None,
                 gpus: Optional[Sequence['outputs.Gpu']] = None):
        pulumi.set(__self__, "adjusted_cost_per_hr", adjusted_cost_per_hr)
        pulumi.set(__self__, "ai_api_id", ai_api_id)
        pulumi.set(__self__, "api_key", api_key)
        pulumi.set(__self__, "consumer_user_id", consumer_user_id)
        pulumi.set(__self__, "container_disk_in_gb", container_disk_in_gb)
        pulumi.set(__self__, "container_registry_auth_id", container_registry_auth_id)
        pulumi.set(__self__, "cost_multiplier", cost_multiplier)
        pulumi.set(__self__, "cost_per_hr", cost_per_hr)
        pulumi.set(__self__, "created_at", created_at)
        pulumi.set(__self__, "desired_status", desired_status)
        pulumi.set(__self__, "docker_args", docker_args)
        pulumi.set(__self__, "docker_id", docker_id)
        pulumi.set(__self__, "gpu_count", gpu_count)
        pulumi.set(__self__, "gpu_power_limit_percent", gpu_power_limit_percent)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "image_name", image_name)
        pulumi.set(__self__, "last_started_at", last_started_at)
        pulumi.set(__self__, "last_status_change", last_status_change)
        pulumi.set(__self__, "locked", locked)
        pulumi.set(__self__, "machine_id", machine_id)
        pulumi.set(__self__, "memory_in_gb", memory_in_gb)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "pod_type", pod_type)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "ports", ports)
        pulumi.set(__self__, "registry", registry)
        pulumi.set(__self__, "template_id", template_id)
        pulumi.set(__self__, "uptime_seconds", uptime_seconds)
        pulumi.set(__self__, "vcpu_count", vcpu_count)
        pulumi.set(__self__, "version", version)
        pulumi.set(__self__, "volume_encrypted", volume_encrypted)
        pulumi.set(__self__, "volume_in_gb", volume_in_gb)
        pulumi.set(__self__, "volume_key", volume_key)
        pulumi.set(__self__, "volume_mount_path", volume_mount_path)
        if env is not None:
            pulumi.set(__self__, "env", env)
        if gpus is not None:
            pulumi.set(__self__, "gpus", gpus)

    @property
    @pulumi.getter(name="adjustedCostPerHr")
    def adjusted_cost_per_hr(self) -> float:
        return pulumi.get(self, "adjusted_cost_per_hr")

    @property
    @pulumi.getter(name="aiApiId")
    def ai_api_id(self) -> str:
        return pulumi.get(self, "ai_api_id")

    @property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> str:
        return pulumi.get(self, "api_key")

    @property
    @pulumi.getter(name="consumerUserId")
    def consumer_user_id(self) -> str:
        return pulumi.get(self, "consumer_user_id")

    @property
    @pulumi.getter(name="containerDiskInGb")
    def container_disk_in_gb(self) -> int:
        return pulumi.get(self, "container_disk_in_gb")

    @property
    @pulumi.getter(name="containerRegistryAuthId")
    def container_registry_auth_id(self) -> str:
        return pulumi.get(self, "container_registry_auth_id")

    @property
    @pulumi.getter(name="costMultiplier")
    def cost_multiplier(self) -> float:
        return pulumi.get(self, "cost_multiplier")

    @property
    @pulumi.getter(name="costPerHr")
    def cost_per_hr(self) -> float:
        return pulumi.get(self, "cost_per_hr")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="desiredStatus")
    def desired_status(self) -> str:
        return pulumi.get(self, "desired_status")

    @property
    @pulumi.getter(name="dockerArgs")
    def docker_args(self) -> str:
        return pulumi.get(self, "docker_args")

    @property
    @pulumi.getter(name="dockerId")
    def docker_id(self) -> str:
        return pulumi.get(self, "docker_id")

    @property
    @pulumi.getter(name="gpuCount")
    def gpu_count(self) -> int:
        return pulumi.get(self, "gpu_count")

    @property
    @pulumi.getter(name="gpuPowerLimitPercent")
    def gpu_power_limit_percent(self) -> int:
        return pulumi.get(self, "gpu_power_limit_percent")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> str:
        return pulumi.get(self, "image_name")

    @property
    @pulumi.getter(name="lastStartedAt")
    def last_started_at(self) -> str:
        return pulumi.get(self, "last_started_at")

    @property
    @pulumi.getter(name="lastStatusChange")
    def last_status_change(self) -> str:
        return pulumi.get(self, "last_status_change")

    @property
    @pulumi.getter
    def locked(self) -> bool:
        return pulumi.get(self, "locked")

    @property
    @pulumi.getter(name="machineId")
    def machine_id(self) -> str:
        return pulumi.get(self, "machine_id")

    @property
    @pulumi.getter(name="memoryInGb")
    def memory_in_gb(self) -> float:
        return pulumi.get(self, "memory_in_gb")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="podType")
    def pod_type(self) -> str:
        return pulumi.get(self, "pod_type")

    @property
    @pulumi.getter
    def port(self) -> int:
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def ports(self) -> str:
        return pulumi.get(self, "ports")

    @property
    @pulumi.getter
    def registry(self) -> 'outputs.PodRegistry':
        return pulumi.get(self, "registry")

    @property
    @pulumi.getter(name="templateId")
    def template_id(self) -> str:
        return pulumi.get(self, "template_id")

    @property
    @pulumi.getter(name="uptimeSeconds")
    def uptime_seconds(self) -> int:
        return pulumi.get(self, "uptime_seconds")

    @property
    @pulumi.getter(name="vcpuCount")
    def vcpu_count(self) -> float:
        return pulumi.get(self, "vcpu_count")

    @property
    @pulumi.getter
    def version(self) -> int:
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="volumeEncrypted")
    def volume_encrypted(self) -> bool:
        return pulumi.get(self, "volume_encrypted")

    @property
    @pulumi.getter(name="volumeInGb")
    def volume_in_gb(self) -> float:
        return pulumi.get(self, "volume_in_gb")

    @property
    @pulumi.getter(name="volumeKey")
    def volume_key(self) -> str:
        return pulumi.get(self, "volume_key")

    @property
    @pulumi.getter(name="volumeMountPath")
    def volume_mount_path(self) -> str:
        return pulumi.get(self, "volume_mount_path")

    @property
    @pulumi.getter
    def env(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "env")

    @property
    @pulumi.getter
    def gpus(self) -> Optional[Sequence['outputs.Gpu']]:
        return pulumi.get(self, "gpus")


@pulumi.output_type
class PodEnv(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class PodRegistry(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "pass":
            suggest = "pass_"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PodRegistry. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PodRegistry.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PodRegistry.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 auth: str,
                 pass_: str,
                 url: str,
                 user: str,
                 username: str):
        pulumi.set(__self__, "auth", auth)
        pulumi.set(__self__, "pass_", pass_)
        pulumi.set(__self__, "url", url)
        pulumi.set(__self__, "user", user)
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def auth(self) -> str:
        return pulumi.get(self, "auth")

    @property
    @pulumi.getter(name="pass")
    def pass_(self) -> str:
        return pulumi.get(self, "pass_")

    @property
    @pulumi.getter
    def url(self) -> str:
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def user(self) -> str:
        return pulumi.get(self, "user")

    @property
    @pulumi.getter
    def username(self) -> str:
        return pulumi.get(self, "username")


@pulumi.output_type
class SavingsPlanInput(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "planLength":
            suggest = "plan_length"
        elif key == "upfrontCost":
            suggest = "upfront_cost"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SavingsPlanInput. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SavingsPlanInput.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SavingsPlanInput.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 plan_length: str,
                 upfront_cost: float):
        pulumi.set(__self__, "plan_length", plan_length)
        pulumi.set(__self__, "upfront_cost", upfront_cost)

    @property
    @pulumi.getter(name="planLength")
    def plan_length(self) -> str:
        return pulumi.get(self, "plan_length")

    @property
    @pulumi.getter(name="upfrontCost")
    def upfront_cost(self) -> float:
        return pulumi.get(self, "upfront_cost")


@pulumi.output_type
class Template(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "advancedStart":
            suggest = "advanced_start"
        elif key == "boundEndpointId":
            suggest = "bound_endpoint_id"
        elif key == "containerDiskInGb":
            suggest = "container_disk_in_gb"
        elif key == "containerRegistryAuthId":
            suggest = "container_registry_auth_id"
        elif key == "dockerArgs":
            suggest = "docker_args"
        elif key == "imageName":
            suggest = "image_name"
        elif key == "isPublic":
            suggest = "is_public"
        elif key == "isRunpod":
            suggest = "is_runpod"
        elif key == "isServerless":
            suggest = "is_serverless"
        elif key == "runtimeInMin":
            suggest = "runtime_in_min"
        elif key == "startJupyter":
            suggest = "start_jupyter"
        elif key == "startScript":
            suggest = "start_script"
        elif key == "startSsh":
            suggest = "start_ssh"
        elif key == "volumeInGb":
            suggest = "volume_in_gb"
        elif key == "volumeMountPath":
            suggest = "volume_mount_path"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in Template. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        Template.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        Template.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 advanced_start: bool,
                 bound_endpoint_id: str,
                 category: str,
                 container_disk_in_gb: int,
                 container_registry_auth_id: str,
                 docker_args: str,
                 earned: float,
                 id: str,
                 image_name: str,
                 is_public: bool,
                 is_runpod: bool,
                 is_serverless: bool,
                 name: str,
                 ports: str,
                 readme: str,
                 runtime_in_min: int,
                 start_jupyter: bool,
                 start_script: str,
                 start_ssh: bool,
                 volume_in_gb: int,
                 volume_mount_path: str,
                 env: Optional[Sequence['outputs.PodEnv']] = None):
        pulumi.set(__self__, "advanced_start", advanced_start)
        pulumi.set(__self__, "bound_endpoint_id", bound_endpoint_id)
        pulumi.set(__self__, "category", category)
        pulumi.set(__self__, "container_disk_in_gb", container_disk_in_gb)
        pulumi.set(__self__, "container_registry_auth_id", container_registry_auth_id)
        pulumi.set(__self__, "docker_args", docker_args)
        pulumi.set(__self__, "earned", earned)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "image_name", image_name)
        pulumi.set(__self__, "is_public", is_public)
        pulumi.set(__self__, "is_runpod", is_runpod)
        pulumi.set(__self__, "is_serverless", is_serverless)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "ports", ports)
        pulumi.set(__self__, "readme", readme)
        pulumi.set(__self__, "runtime_in_min", runtime_in_min)
        pulumi.set(__self__, "start_jupyter", start_jupyter)
        pulumi.set(__self__, "start_script", start_script)
        pulumi.set(__self__, "start_ssh", start_ssh)
        pulumi.set(__self__, "volume_in_gb", volume_in_gb)
        pulumi.set(__self__, "volume_mount_path", volume_mount_path)
        if env is not None:
            pulumi.set(__self__, "env", env)

    @property
    @pulumi.getter(name="advancedStart")
    def advanced_start(self) -> bool:
        return pulumi.get(self, "advanced_start")

    @property
    @pulumi.getter(name="boundEndpointId")
    def bound_endpoint_id(self) -> str:
        return pulumi.get(self, "bound_endpoint_id")

    @property
    @pulumi.getter
    def category(self) -> str:
        return pulumi.get(self, "category")

    @property
    @pulumi.getter(name="containerDiskInGb")
    def container_disk_in_gb(self) -> int:
        return pulumi.get(self, "container_disk_in_gb")

    @property
    @pulumi.getter(name="containerRegistryAuthId")
    def container_registry_auth_id(self) -> str:
        return pulumi.get(self, "container_registry_auth_id")

    @property
    @pulumi.getter(name="dockerArgs")
    def docker_args(self) -> str:
        return pulumi.get(self, "docker_args")

    @property
    @pulumi.getter
    def earned(self) -> float:
        return pulumi.get(self, "earned")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> str:
        return pulumi.get(self, "image_name")

    @property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> bool:
        return pulumi.get(self, "is_public")

    @property
    @pulumi.getter(name="isRunpod")
    def is_runpod(self) -> bool:
        return pulumi.get(self, "is_runpod")

    @property
    @pulumi.getter(name="isServerless")
    def is_serverless(self) -> bool:
        return pulumi.get(self, "is_serverless")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def ports(self) -> str:
        return pulumi.get(self, "ports")

    @property
    @pulumi.getter
    def readme(self) -> str:
        return pulumi.get(self, "readme")

    @property
    @pulumi.getter(name="runtimeInMin")
    def runtime_in_min(self) -> int:
        return pulumi.get(self, "runtime_in_min")

    @property
    @pulumi.getter(name="startJupyter")
    def start_jupyter(self) -> bool:
        return pulumi.get(self, "start_jupyter")

    @property
    @pulumi.getter(name="startScript")
    def start_script(self) -> str:
        return pulumi.get(self, "start_script")

    @property
    @pulumi.getter(name="startSsh")
    def start_ssh(self) -> bool:
        return pulumi.get(self, "start_ssh")

    @property
    @pulumi.getter(name="volumeInGb")
    def volume_in_gb(self) -> int:
        return pulumi.get(self, "volume_in_gb")

    @property
    @pulumi.getter(name="volumeMountPath")
    def volume_mount_path(self) -> str:
        return pulumi.get(self, "volume_mount_path")

    @property
    @pulumi.getter
    def env(self) -> Optional[Sequence['outputs.PodEnv']]:
        return pulumi.get(self, "env")


